/* Set Up Your Environment */

libname RDExamp "C:\users\sasdemo\RD_Examples"; 
%let test_env = stressholding;
proc risk;   
   env new=RDExamp.&test_env;   
   env save; 
run;

/* Define Your Portfolio */
data RDExamp.instdata;
  input insttype $12. instid $8. holding;
  datalines;
TechCompany instid1 1000000
BankCompany instid2 1000000
;

proc risk;
  env open=RDExamp.&test_env;
  instdata Instruments file=RDExamp.instdata format=simple;
  env save;
run;

/* Register Market Data */
data RDExamp.mktdata;
  TEC=15; 
  BNK=30;  
run;

data RDExamp.scendata;
  length _cvalue_ $ 20;
  input _type_ $ _name_ $ _value_ _ctype_ $ _cvalue_ $;
  datalines;
absolute holding -500000 insttype TechCompany
value    TEC      10     none     none          
run;

proc risk;
   env open=RDExamp.&test_env;
   declare riskfactors=(TEC num var, BNK num var);
   marketdata Market file=RDExamp.mktdata  type=current;
   marketdata TechCoScenario file=RDExamp.scendata type=scenarioanalysis;
   env save;
run;

/* Define Valuation Methods and Instrument Types */
proc compile env=RDExamp.&test_env outlib=RDExamp.&test_env;
  method Tech_Price kind=price;
    _value_ = TEC;
  endmethod;
  method Bank_Price kind=price;
    _value_ = BNK;
  endmethod;
run;

proc risk;
  env open=RDExamp.&test_env;
  instrument TechCompany methods=(Price Tech_Price) variables = (holding);
  instrument BankCompany methods=(Price Bank_Price) variables = (holding);
  env save;
run;

/* Specify the Analysis and Create the Project */
proc risk;
  env open=RDExamp.&test_env;
  sources InstDataSource (Instruments);
  read sources=InstDataSource out=Portfolio;
  crossclass InstTypeCC (Insttype);

  scenario TechCompanyScen 
     data = TechCoScenario 
     label = "TechCompany Share Price Decrease"; 
  
  project Project
     analysis=(TechCompanyScen)
     portfolio=Portfolio
     crossclass=InstTypeCC
     data=( Market )
     rundate = '07JAN2013'd;
env save;
run;

/* Run the Project */
proc risk;
    env open=RDExamp.&test_env;
    runproject Project
    out= StressHolding_Output
    options=(outall);
  env save;
run;
